==> ochusha-0.4.9.6.tar.bz2: ochusha-0.4.9.6/gtk2/marshal.h <==

#ifndef __ochusha_marshal_MARSHAL_H__
#define __ochusha_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:BOOLEAN (marshal.list:1) */
#define ochusha_marshal_VOID__BOOLEAN	g_cclosure_marshal_VOID__BOOLEAN

/* VOID:BOXED (marshal.list:2) */
#define ochusha_marshal_VOID__BOXED	g_cclosure_marshal_VOID__BOXED

/* VOID:ENUM (marshal.list:3) */
#define ochusha_marshal_VOID__ENUM	g_cclosure_marshal_VOID__ENUM

/* VOID:INT (marshal.list:4) */
#define ochusha_marshal_VOID__INT	g_cclosure_marshal_VOID__INT

/* VOID:OBJECT (marshal.list:5) */
#define ochusha_marshal_VOID__OBJECT	g_cclosure_marshal_VOID__OBJECT

/* VOID:POINTER (marshal.list:6) */
#define ochusha_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER

/* VOID:VOID (marshal.list:7) */
#define ochusha_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID

/* VOID:ENUM,INT (marshal.list:8) */
extern void ochusha_marshal_VOID__ENUM_INT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);

/* VOID:OBJECT,OBJECT (marshal.list:9) */
extern void ochusha_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);

/* VOID:OBJECT,BOOLEAN (marshal.list:10) */
extern void ochusha_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
                                                  const GValue *param_values,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);

/* VOID:POINTER,OBJECT (marshal.list:11) */
extern void ochusha_marshal_VOID__POINTER_OBJECT (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
                                                  const GValue *param_values,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);

/* VOID:BOXED,POINTER,STRING (marshal.list:12) */
extern void ochusha_marshal_VOID__BOXED_POINTER_STRING (GClosure     *closure,
                                                        GValue       *return_value,
                                                        guint         n_param_values,
                                                        const GValue *param_values,
                                                        gpointer      invocation_hint,
                                                        gpointer      marshal_data);

/* VOID:ENUM,INT,BOOLEAN (marshal.list:13) */
extern void ochusha_marshal_VOID__ENUM_INT_BOOLEAN (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
                                                    const GValue *param_values,
                                                    gpointer      invocation_hint,
                                                    gpointer      marshal_data);

/* VOID:OBJECT,BOOLEAN,BOOLEAN (marshal.list:14) */
extern void ochusha_marshal_VOID__OBJECT_BOOLEAN_BOOLEAN (GClosure     *closure,
                                                          GValue       *return_value,
                                                          guint         n_param_values,
                                                          const GValue *param_values,
                                                          gpointer      invocation_hint,
                                                          gpointer      marshal_data);

/* VOID:OBJECT,BOOLEAN,BOOLEAN,BOOLEAN (marshal.list:15) */
extern void ochusha_marshal_VOID__OBJECT_BOOLEAN_BOOLEAN_BOOLEAN (GClosure     *closure,
                                                                  GValue       *return_value,
                                                                  guint         n_param_values,
                                                                  const GValue *param_values,
                                                                  gpointer      invocation_hint,
                                                                  gpointer      marshal_data);

/* VOID:OBJECT,OBJECT,STRING,ENUM (marshal.list:16) */
extern void ochusha_marshal_VOID__OBJECT_OBJECT_STRING_ENUM (GClosure     *closure,
                                                             GValue       *return_value,
                                                             guint         n_param_values,
                                                             const GValue *param_values,
                                                             gpointer      invocation_hint,
                                                             gpointer      marshal_data);

/* VOID:POINTER,POINTER,POINTER,POINTER (marshal.list:17) */
extern void ochusha_marshal_VOID__POINTER_POINTER_POINTER_POINTER (GClosure     *closure,
                                                                   GValue       *return_value,
                                                                   guint         n_param_values,
                                                                   const GValue *param_values,
                                                                   gpointer      invocation_hint,
                                                                   gpointer      marshal_data);

/* BOOLEAN:ENUM,INT (marshal.list:18) */
extern void ochusha_marshal_BOOLEAN__ENUM_INT (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);

/* BOOLEAN:OBJECT (marshal.list:19) */
extern void ochusha_marshal_BOOLEAN__OBJECT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);

/* BOOLEAN:OBJECT,OBJECT (marshal.list:20) */
extern void ochusha_marshal_BOOLEAN__OBJECT_OBJECT (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
                                                    const GValue *param_values,
                                                    gpointer      invocation_hint,
                                                    gpointer      marshal_data);

/* BOOLEAN:BOXED,POINTER,STRING (marshal.list:21) */
extern void ochusha_marshal_BOOLEAN__BOXED_POINTER_STRING (GClosure     *closure,
                                                           GValue       *return_value,
                                                           guint         n_param_values,
                                                           const GValue *param_values,
                                                           gpointer      invocation_hint,
                                                           gpointer      marshal_data);

/* BOOLEAN:STRING,INT,BOOLEAN,BOOLEAN,BOOLEAN (marshal.list:22) */
extern void ochusha_marshal_BOOLEAN__STRING_INT_BOOLEAN_BOOLEAN_BOOLEAN (GClosure     *closure,
                                                                         GValue       *return_value,
                                                                         guint         n_param_values,
                                                                         const GValue *param_values,
                                                                         gpointer      invocation_hint,
                                                                         gpointer      marshal_data);

G_END_DECLS

#endif /* __ochusha_marshal_MARSHAL_H__ */

==> ochusha-0.5.tar.bz2: ochusha-0.5/gtk2/marshal.h <==

#ifndef __ochusha_marshal_MARSHAL_H__
#define __ochusha_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:BOOLEAN (./marshal.list:1) */
#define ochusha_marshal_VOID__BOOLEAN	g_cclosure_marshal_VOID__BOOLEAN

/* VOID:BOXED (./marshal.list:2) */
#define ochusha_marshal_VOID__BOXED	g_cclosure_marshal_VOID__BOXED

/* VOID:ENUM (./marshal.list:3) */
#define ochusha_marshal_VOID__ENUM	g_cclosure_marshal_VOID__ENUM

/* VOID:INT (./marshal.list:4) */
#define ochusha_marshal_VOID__INT	g_cclosure_marshal_VOID__INT

/* VOID:OBJECT (./marshal.list:5) */
#define ochusha_marshal_VOID__OBJECT	g_cclosure_marshal_VOID__OBJECT

/* VOID:POINTER (./marshal.list:6) */
#define ochusha_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER

/* VOID:VOID (./marshal.list:7) */
#define ochusha_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID

/* VOID:ENUM,INT (./marshal.list:8) */
extern void ochusha_marshal_VOID__ENUM_INT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);

/* VOID:OBJECT,OBJECT (./marshal.list:9) */
extern void ochusha_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);

/* VOID:OBJECT,BOOLEAN (./marshal.list:10) */
extern void ochusha_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
                                                  const GValue *param_values,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);

/* VOID:POINTER,OBJECT (./marshal.list:11) */
extern void ochusha_marshal_VOID__POINTER_OBJECT (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
                                                  const GValue *param_values,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);

/* VOID:BOXED,POINTER,STRING (./marshal.list:12) */
extern void ochusha_marshal_VOID__BOXED_POINTER_STRING (GClosure     *closure,
                                                        GValue       *return_value,
                                                        guint         n_param_values,
                                                        const GValue *param_values,
                                                        gpointer      invocation_hint,
                                                        gpointer      marshal_data);

/* VOID:ENUM,INT,BOOLEAN (./marshal.list:13) */
extern void ochusha_marshal_VOID__ENUM_INT_BOOLEAN (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
                                                    const GValue *param_values,
                                                    gpointer      invocation_hint,
                                                    gpointer      marshal_data);

/* VOID:OBJECT,BOOLEAN,BOOLEAN (./marshal.list:14) */
extern void ochusha_marshal_VOID__OBJECT_BOOLEAN_BOOLEAN (GClosure     *closure,
                                                          GValue       *return_value,
                                                          guint         n_param_values,
                                                          const GValue *param_values,
                                                          gpointer      invocation_hint,
                                                          gpointer      marshal_data);

/* VOID:OBJECT,BOOLEAN,BOOLEAN,BOOLEAN (./marshal.list:15) */
extern void ochusha_marshal_VOID__OBJECT_BOOLEAN_BOOLEAN_BOOLEAN (GClosure     *closure,
                                                                  GValue       *return_value,
                                                                  guint         n_param_values,
                                                                  const GValue *param_values,
                                                                  gpointer      invocation_hint,
                                                                  gpointer      marshal_data);

/* VOID:OBJECT,OBJECT,STRING,ENUM (./marshal.list:16) */
extern void ochusha_marshal_VOID__OBJECT_OBJECT_STRING_ENUM (GClosure     *closure,
                                                             GValue       *return_value,
                                                             guint         n_param_values,
                                                             const GValue *param_values,
                                                             gpointer      invocation_hint,
                                                             gpointer      marshal_data);

/* VOID:POINTER,POINTER,POINTER,POINTER (./marshal.list:17) */
extern void ochusha_marshal_VOID__POINTER_POINTER_POINTER_POINTER (GClosure     *closure,
                                                                   GValue       *return_value,
                                                                   guint         n_param_values,
                                                                   const GValue *param_values,
                                                                   gpointer      invocation_hint,
                                                                   gpointer      marshal_data);

/* BOOLEAN:ENUM,INT (./marshal.list:18) */
extern void ochusha_marshal_BOOLEAN__ENUM_INT (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);

/* BOOLEAN:OBJECT (./marshal.list:19) */
extern void ochusha_marshal_BOOLEAN__OBJECT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);

/* BOOLEAN:OBJECT,OBJECT (./marshal.list:20) */
extern void ochusha_marshal_BOOLEAN__OBJECT_OBJECT (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
                                                    const GValue *param_values,
                                                    gpointer      invocation_hint,
                                                    gpointer      marshal_data);

/* BOOLEAN:BOXED,POINTER,STRING (./marshal.list:21) */
extern void ochusha_marshal_BOOLEAN__BOXED_POINTER_STRING (GClosure     *closure,
                                                           GValue       *return_value,
                                                           guint         n_param_values,
                                                           const GValue *param_values,
                                                           gpointer      invocation_hint,
                                                           gpointer      marshal_data);

/* BOOLEAN:STRING,INT,BOOLEAN,BOOLEAN,BOOLEAN (./marshal.list:22) */
extern void ochusha_marshal_BOOLEAN__STRING_INT_BOOLEAN_BOOLEAN_BOOLEAN (GClosure     *closure,
                                                                         GValue       *return_value,
                                                                         guint         n_param_values,
                                                                         const GValue *param_values,
                                                                         gpointer      invocation_hint,
                                                                         gpointer      marshal_data);

G_END_DECLS

#endif /* __ochusha_marshal_MARSHAL_H__ */
